<?php
/**
 * @author mail[at]doerr-softwaredevelopment[dot]com Joachim Doerr
 * @package redaxo5
 * @license MIT
 */
$minMysqlVersion = '5.6.15';
$mysqlVersion = rex_sql::getServerVersion(); 

if(strpos($mysqlVersion, 'MariaDB') !== false){
    $minMysqlVersion = '5.5.5-10.1';
}
if (rex_string::versionCompare($mysqlVersion, $minMysqlVersion, '<')) {
    $message = rex_i18n::hasMsg('sql_database_min_version')
        ? rex_i18n::msg('sql_database_min_version', $mysqlVersion, $minMysqlVersion)
        : "The MySQL version $mysqlVersion is too old, you need at least version $minMysqlVersion!";
    throw new rex_functional_exception($message);
}
else {
rex_sql_table::get(rex::getTable('forcal_categories'))
    ->ensurePrimaryIdColumn()
    ->ensureColumn(new rex_sql_column('color', 'varchar(40)', true))
    ->ensureColumn(new rex_sql_column('status', 'int(1)', true, '1'))
    ->ensureColumn(new rex_sql_column('name_1', 'varchar(255)', false, ''))
    ->ensureColumn(new rex_sql_column('createdate', 'datetime', false, 'CURRENT_TIMESTAMP'))
    ->ensureColumn(new rex_sql_column('updatedate', 'datetime', false, 'CURRENT_TIMESTAMP', 'on update CURRENT_TIMESTAMP'))
    ->ensureColumn(new rex_sql_column('createuser', 'varchar(255)', true))
    ->ensureColumn(new rex_sql_column('updateuser', 'varchar(255)', true))
    ->ensure();

rex_sql_table::get(rex::getTable('forcal_entries'))
    ->ensureColumn(new rex_sql_column('id', 'int(11) unsigned', false, null, 'auto_increment'))
    ->ensureColumn(new rex_sql_column('uid', 'varchar(192)'))
    ->ensureColumn(new rex_sql_column('start_date', 'date'))
    ->ensureColumn(new rex_sql_column('end_date', 'date'))
    ->ensureColumn(new rex_sql_column('start_time', 'time'))
    ->ensureColumn(new rex_sql_column('end_time', 'time'))
    ->ensureColumn(new rex_sql_column('category', 'int(5)', true))
    ->ensureColumn(new rex_sql_column('venue', 'int(5)', true))
    ->ensureColumn(new rex_sql_column('status', 'int(1)', true, '1'))
    ->ensureColumn(new rex_sql_column('name_1', 'varchar(255)', false, ''))
    ->ensureColumn(new rex_sql_column('teaser_1', 'text'))
    ->ensureColumn(new rex_sql_column('text_1', 'text'))
    ->ensureColumn(new rex_sql_column('type', 'varchar(25)', true))
    ->ensureColumn(new rex_sql_column('full_time', 'varchar(3)', true))
    ->ensureColumn(new rex_sql_column('repeat', 'varchar(25)', true))
    ->ensureColumn(new rex_sql_column('repeat_year', 'int(11)', true))
    ->ensureColumn(new rex_sql_column('repeat_week', 'int(11)', true))
    ->ensureColumn(new rex_sql_column('repeat_month', 'int(11)', true))
    ->ensureColumn(new rex_sql_column('repeat_month_week', 'varchar(15)', true))
    ->ensureColumn(new rex_sql_column('repeat_day', 'varchar(3)', true))
    ->ensureColumn(new rex_sql_column('end_repeat_date', 'date', true))
    ->ensureColumn(new rex_sql_column('createdate', 'datetime', false, 'CURRENT_TIMESTAMP'))
    ->ensureColumn(new rex_sql_column('updatedate', 'datetime', false, 'CURRENT_TIMESTAMP', 'on update CURRENT_TIMESTAMP'))
    ->ensureColumn(new rex_sql_column('createuser', 'varchar(255)'))
    ->ensureColumn(new rex_sql_column('updateuser', 'varchar(255)'))
    ->setPrimaryKey('id')
    ->ensure();

rex_sql_table::get(rex::getTable('forcal_venues'))
    ->ensureColumn(new rex_sql_column('id', 'int(11)', false, null, 'auto_increment'))
    ->ensureColumn(new rex_sql_column('status', 'int(1)', true, '1'))
    ->ensureColumn(new rex_sql_column('name_1', 'text'))
    ->ensureColumn(new rex_sql_column('createdate', 'datetime', false, 'CURRENT_TIMESTAMP'))
    ->ensureColumn(new rex_sql_column('updatedate', 'datetime', false, 'CURRENT_TIMESTAMP', 'on update CURRENT_TIMESTAMP'))
    ->ensureColumn(new rex_sql_column('createuser', 'varchar(255)'))
    ->ensureColumn(new rex_sql_column('updateuser', 'varchar(255)'))
    ->ensureColumn(new rex_sql_column('city', 'text', true))
    ->ensureColumn(new rex_sql_column('zip', 'text', true))
    ->ensureColumn(new rex_sql_column('street', 'text', true))
    ->ensureColumn(new rex_sql_column('housenumber', 'text', true))
    ->ensureColumn(new rex_sql_column('country', 'text', true))
    ->setPrimaryKey('id')
    ->ensure();
if (rex_string::versionCompare($this->getVersion(), '1.6', '<')) {

    $table = rex::getTablePrefix() . "forcal_categories";

    try {
        rex_sql::factory()->setQuery("UPDATE " . rex::getTablePrefix() . "forcal_entries SET full_time = '|1|' WHERE start_time = '00:00:00' AND end_time = '00:00:00' AND full_time IS NULL;");
    } catch (rex_sql_exception $e) {
        rex_logger::logException($e);
    }

}
}
